Naas manager

{{ this.accountBalance.balance.toFixed(2) }}⚡ ⇄ {{this.accountBalance.balance_dollar.toFixed(2)}}$ ⓘ The balance takes into account processed transactions. It is updated every 15min.
Credits available

Access all the templates created by the community in Naas awesome-notebooks Github repository.

Monitor active features in the "__production__" folder of your JupyterLab: scheduler, asset, webhook, notification.

Access the logs of all your jobs executions, and see errors messages.

Access the complete detail of your activity with the Naas transactions template.

####

Version: {{env.version}} Update to {{env.latest_version}}

Any questions? Please contact us.

🙏 We're working hard to build Naas, and need more help!
If you know anybody who would like to contribute to open source - in engineering, marketing roles, and more - please let us know and tell your friends!